==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'သိုလောင်မှု ပြန်ထည့်သွင်းရန်',

	// I
	'info_restauration_sauvegarde' => 'အရံသိမ်းထားသော@archive@ကို ပြန်လည်ဖော်ထုတ်ပါ', # MODIF
	'info_sauvegarde' => 'အရံသိမ်းဆည်းပါ',
	'info_sauvegarde_reussi_02' => 'အချက်လက်သိုလှောင်မှုကို @archive@တွင်သင်သိမ်းနိုင်သည်',
	'info_sauvegarde_reussi_03' => 'စီမံခန့်ခွဲမှုကို ပြန်သွားပါ',
	'info_sauvegarde_reussi_04' => 'သင့်ဝက်ဘ်ဆိုက်၏',

	// T
	'texte_admin_tech_01' => 'ဤရွေးချယ်မှုသည် လမ်းညွှန်မှု@dossier@ ထဲတွင် သိုလှောင်မည့် ဖိုင်များကို ရွေးချယ်ပေးပါမည်။ ​အခန်းကဏ္ဍများနှင့် ဆောင်းပါးများတွင် အသုံးပြုသော ပုံများနှင့် စာရွက်စာတမ်းများ ပါဝင်သော @img@၊ လမ်းညွှန်မှုများကို ပြန်လည်ရရှိအောင် လုပ်ရန်လည်း မမေ့ပါနှင့်။',
	'texte_admin_tech_02' => 'သတိပေးချက်။ ဤအရံသိမ်းဆည်းထားမှုကို မူကွဲတူသော SPIP အောက်တွင်သာ ပြန်လည်ထည့်သွင်း၍ ရနိုင်မည်။ သိုလှောင်မှုကို ဖျက်ပစ်ခြင်း လုံးဝလုံးဝ မပြုလုပ်သင့်ပါ အဘယ့်ကြောင့်ဆိုသော် မြှင့်တင်မှုပြုပြီးရင် အရံသိမ်းဆည်းထားသော သိုလှောင်မှုကို ပြန်လည်ထည့်သွင်းရန် လိုအပ်နိုင်သည်။ ပိုမိုသိရှိနိုင်ရန် <a href="@spipnet@">SPIP စာရွက်စာတမ်းများ</a> ကိုလာလည်ပါ။', # MODIF
	'texte_restaurer_base' => 'အရံသိမ်းထားသော အချက်အလက်များကို ပြန်လည်ဖော်ထုတ်ပါ',
	'texte_restaurer_sauvegarde' => 'ဤရွေးချယ်မှုသည် အရံသိမ်းဆည်းထားသော သိုလှောင်မှုကို ပြန်လည်ထည့်သွင်းနိုင်ရန်ဖြစ်သည်။ ဤသို့လုပ်ဆောင်နိုင်ရန် အရံသိမ်းဆည်းမှုကို @dossier@ အညွှန်းထဲတွင် ရှိမှဖြစ်မည်။ ဒီလုပ်ဆောင်မှုကို အထူးသတိပြုပါ။ <b>လုပ်ဆောင်မှုအမှား တစုံတရာ ရှိခဲ့ရင် ပြန်လည်ပြူပြင်၍ မရတော့ပါဘူး။</b>', # MODIF
	'texte_sauvegarde' => 'အချက်လက်သိုလှောင်မှုအကြောင်ရာများကို အရံသိမ်းဆည်းထားပါ',
	'texte_sauvegarde_base' => 'အချက်လက်သိုလှောင်မှုကို အရံသိမ်းထားပါ'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=my
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'သိုလောင်မှု ပြန်ထည့်သွင်းရန်',

	// I
	'info_restauration_sauvegarde' => 'အရံသိမ်းထားသော@archive@ကို ပြန်လည်ဖော်ထုတ်ပါ', # MODIF
	'info_sauvegarde' => 'အရံသိမ်းဆည်းပါ',
	'info_sauvegarde_reussi_02' => 'အချက်လက်သိုလှောင်မှုကို @archive@တွင်သင်သိမ်းနိုင်သည်',
	'info_sauvegarde_reussi_03' => 'စီမံခန့်ခွဲမှုကို ပြန်သွားပါ',
	'info_sauvegarde_reussi_04' => 'သင့်ဝက်ဘ်ဆိုက်၏',

	// T
	'texte_admin_tech_01' => 'ဤရွေးချယ်မှုသည် လမ်းညွှန်မှု@dossier@ ထဲတွင် သိုလှောင်မည့် ဖိုင်များကို ရွေးချယ်ပေးပါမည်။ ​အခန်းကဏ္ဍများနှင့် ဆောင်းပါးများတွင် အသုံးပြုသော ပုံများနှင့် စာရွက်စာတမ်းများ ပါဝင်သော @img@၊ လမ်းညွှန်မှုများကို ပြန်လည်ရရှိအောင် လုပ်ရန်လည်း မမေ့ပါနှင့်။',
	'texte_admin_tech_02' => 'သတိပေးချက်။ ဤအရံသိမ်းဆည်းထားမှုကို မူကွဲတူသော SPIP အောက်တွင်သာ ပြန်လည်ထည့်သွင်း၍ ရနိုင်မည်။ သိုလှောင်မှုကို ဖျက်ပစ်ခြင်း လုံးဝလုံးဝ မပြုလုပ်သင့်ပါ အဘယ့်ကြောင့်ဆိုသော် မြှင့်တင်မှုပြုပြီးရင် အရံသိမ်းဆည်းထားသော သိုလှောင်မှုကို ပြန်လည်ထည့်သွင်းရန် လိုအပ်နိုင်သည်။ ပိုမိုသိရှိနိုင်ရန် <a href="@spipnet@">SPIP စာရွက်စာတမ်းများ</a> ကိုလာလည်ပါ။', # MODIF
	'texte_restaurer_base' => 'အရံသိမ်းထားသော အချက်အလက်များကို ပြန်လည်ဖော်ထုတ်ပါ',
	'texte_restaurer_sauvegarde' => 'ဤရွေးချယ်မှုသည် အရံသိမ်းဆည်းထားသော သိုလှောင်မှုကို ပြန်လည်ထည့်သွင်းနိုင်ရန်ဖြစ်သည်။ ဤသို့လုပ်ဆောင်နိုင်ရန် အရံသိမ်းဆည်းမှုကို @dossier@ အညွှန်းထဲတွင် ရှိမှဖြစ်မည်။ ဒီလုပ်ဆောင်မှုကို အထူးသတိပြုပါ။ <b>လုပ်ဆောင်မှုအမှား တစုံတရာ ရှိခဲ့ရင် ပြန်လည်ပြူပြင်၍ မရတော့ပါဘူး။</b>', # MODIF
	'texte_sauvegarde' => 'အချက်လက်သိုလှောင်မှုအကြောင်ရာများကို အရံသိမ်းဆည်းထားပါ',
	'texte_sauvegarde_base' => 'အချက်လက်သိုလှောင်မှုကို အရံသိမ်းထားပါ',
];
